@@ -6,4 +6,4 @@ class VouchProxyUserBackend(RemoteUserBackend):
     def __init__(self, *args, **kwargs):
         self.create_unknown_user = getattr(settings, 'VOUCH_PROXY_CREATE_UNKNOWN_USER', True)
 
-        super(VouchProxyUserBackend).__init__(*args, **kwargs)
\ No newline at end of file
+        super().__init__(*args, **kwargs)
\ No newline at end of file
